@@ -34,8 +34,8 @@
 
 import os as _os
 from socket import timeout as _SocketTimeout
-from io import BytesIO as _BytesIO
 from collections import namedtuple as _namedtuple
+from contextlib import closing
 
 __all__ = ['SCPError', 'SCPTimeoutError', 'Write', 'WriteDir',
            'Read', 'ReadDir']
@@ -486,7 +486,7 @@ class ReadDir(_ReadBase):
             raise SCPError('local directory {0!r} does not exist'.format(
                                                           local_dirname))
 
-        for op in scp._receive(remote_dirname):
+        for op in self._receive(remote_dirname):
             if _os.path.isabs(op.path):
                 raise SCPError('{0!r} is an absolute path'.format(op.path))
             if '..' in op.path:
